[QGIS Commit] r9529 - in trunk/qgis: python/core python/plugins/mapserver_export src/app src/app/legend src/core src/core/composer src/core/raster src/gui src/providers/wfs src/providers/wms tests/testdata tools/mapserver_export

svn_qgis at osgeo.org svn_qgis at osgeo.org
Fri Oct 24 07:00:32 EDT 2008


Author: timlinux
Date: 2008-10-24 07:00:31 -0400 (Fri, 24 Oct 2008)
New Revision: 9529

Modified:
   trunk/qgis/python/core/qgsmaplayer.sip
   trunk/qgis/python/core/qgsrasterdataprovider.sip
   trunk/qgis/python/core/qgsrasterlayer.sip
   trunk/qgis/python/core/qgsvectorlayer.sip
   trunk/qgis/python/plugins/mapserver_export/ms_export.py
   trunk/qgis/src/app/legend/qgslegendlayerfilegroup.cpp
   trunk/qgis/src/app/qgisapp.cpp
   trunk/qgis/src/app/qgsmapserverexport.cpp
   trunk/qgis/src/app/qgsmaptoolidentify.cpp
   trunk/qgis/src/app/qgsrasterlayerproperties.cpp
   trunk/qgis/src/app/qgsserversourceselect.cpp
   trunk/qgis/src/app/qgsvectorlayerproperties.cpp
   trunk/qgis/src/core/composer/qgscomposeritem.cpp
   trunk/qgis/src/core/composer/qgscomposeritem.h
   trunk/qgis/src/core/composer/qgscomposerlabel.cpp
   trunk/qgis/src/core/composer/qgscomposerlegend.cpp
   trunk/qgis/src/core/composer/qgscomposerscalebar.cpp
   trunk/qgis/src/core/composer/qgscomposerscalebar.h
   trunk/qgis/src/core/composer/qgscomposition.cpp
   trunk/qgis/src/core/composer/qgsdoubleboxscalebarstyle.cpp
   trunk/qgis/src/core/composer/qgsscalebarstyle.cpp
   trunk/qgis/src/core/composer/qgssingleboxscalebarstyle.cpp
   trunk/qgis/src/core/composer/qgsticksscalebarstyle.cpp
   trunk/qgis/src/core/qgshttptransaction.cpp
   trunk/qgis/src/core/qgshttptransaction.h
   trunk/qgis/src/core/qgsmaplayer.cpp
   trunk/qgis/src/core/qgsmaplayer.h
   trunk/qgis/src/core/qgsmaprenderer.cpp
   trunk/qgis/src/core/qgsmaprenderer.h
   trunk/qgis/src/core/qgsrasterdataprovider.h
   trunk/qgis/src/core/qgsvectorlayer.cpp
   trunk/qgis/src/core/qgsvectorlayer.h
   trunk/qgis/src/core/raster/qgsrasterlayer.cpp
   trunk/qgis/src/core/raster/qgsrasterlayer.h
   trunk/qgis/src/gui/qgsmapcanvas.cpp
   trunk/qgis/src/providers/wfs/qgswfsprovider.cpp
   trunk/qgis/src/providers/wms/qgswmsprovider.cpp
   trunk/qgis/src/providers/wms/qgswmsprovider.h
   trunk/qgis/tests/testdata/landsat_875.qml
   trunk/qgis/tests/testdata/lines.qml
   trunk/qgis/tests/testdata/lines_continuous_symbol.qml
   trunk/qgis/tests/testdata/lines_graduated_symbol.qml
   trunk/qgis/tests/testdata/lines_single_symbol.qml
   trunk/qgis/tests/testdata/lines_uniquevalue_symbol.qml
   trunk/qgis/tests/testdata/maprender_testdata.qml
   trunk/qgis/tests/testdata/points.qml
   trunk/qgis/tests/testdata/points_continuous_symbol.qml
   trunk/qgis/tests/testdata/points_graduated_symbol.qml
   trunk/qgis/tests/testdata/points_single_symbol.qml
   trunk/qgis/tests/testdata/points_uniquevalue_symbol.qml
   trunk/qgis/tests/testdata/polys.qml
   trunk/qgis/tests/testdata/polys_continuous_symbol.qml
   trunk/qgis/tests/testdata/polys_graduated_symbol.qml
   trunk/qgis/tests/testdata/polys_single_symbol.qml
   trunk/qgis/tests/testdata/polys_uniquevalue_symbol.qml
   trunk/qgis/tools/mapserver_export/ms_export.py
   trunk/qgis/tools/mapserver_export/qgsmapserverexport.cpp
Log:
API cleanups

Modified: trunk/qgis/python/core/qgsmaplayer.sip
===================================================================
--- trunk/qgis/python/core/qgsmaplayer.sip	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/python/core/qgsmaplayer.sip	2008-10-24 11:00:31 UTC (rev 9529)
@@ -160,7 +160,7 @@
     virtual bool copySymbologySettings(const QgsMapLayer& other) = 0;
 
     /** Returns true if this layer can be in the same symbology group with another layer */
-    virtual bool isSymbologyCompatible(const QgsMapLayer& other) const = 0;
+    virtual bool hasCompatibleSymbology(const QgsMapLayer& other) const = 0;
 
     /** Accessor for transparency level. */
     unsigned int getTransparency();
@@ -174,7 +174,7 @@
      * Interactive users of this provider can then, for example,
      * call a QMessageBox to display the contents.
      */
-    virtual QString errorCaptionString();
+    virtual QString lastErrorTitle();
   
     /**
      * If an operation returns 0 (e.g. draw()), this function
@@ -182,13 +182,13 @@
      * Interactive users of this provider can then, for example,
      * call a QMessageBox to display the contents.
      */
-    virtual QString errorString();
+    virtual QString lastError();
 
     /** Returns layer's spatial reference system */
     const QgsCoordinateReferenceSystem& srs();
     
     /** Sets layer's spatial reference system */
-    void setSrs(const QgsCoordinateReferenceSystem& srs);
+    void setCrs(const QgsCoordinateReferenceSystem& srs);
 
     /** A convenience function to capitalise the layer name */
     static QString capitaliseLayerName(const QString name);
@@ -251,16 +251,16 @@
     virtual void invalidTransformInput();
 
     /** Accessor and mutator for the minimum scale member */
-    void setMinScale(float theMinScale);
-    float minScale();
+    void setMinimumScale(float theMinScale);
+    float minimumScale();
 
     /** Accessor and mutator for the maximum scale member */
-    void setMaxScale(float theMaxScale);
-    float maxScale();
+    void setMaximumScale(float theMaxScale);
+    float maximumScale();
 
     /** Accessor and mutator for the scale based visilibility flag */
-    void setScaleBasedVisibility( bool theVisibilityFlag);
-    bool scaleBasedVisibility();
+    void toggleScaleBasedVisibility( bool theVisibilityFlag);
+    bool hasScaleBasedVisibility();
 
 signals:
 

Modified: trunk/qgis/python/core/qgsrasterdataprovider.sip
===================================================================
--- trunk/qgis/python/core/qgsrasterdataprovider.sip	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/python/core/qgsrasterdataprovider.sip	2008-10-24 11:00:31 UTC (rev 9529)
@@ -107,7 +107,7 @@
      * call a QMessageBox to display the contents.
      *
      */
-    virtual QString errorCaptionString() = 0;
+    virtual QString lastErrorTitle() = 0;
 
     /**
      * \brief   Returns the verbose error text for the last error in this provider
@@ -118,7 +118,7 @@
      * call a QMessageBox to display the contents.
      *
      */
-    virtual QString errorString() = 0;
+    virtual QString lastError() = 0;
 
 
 protected:

Modified: trunk/qgis/python/core/qgsrasterlayer.sip
===================================================================
--- trunk/qgis/python/core/qgsrasterlayer.sip	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/python/core/qgsrasterlayer.sip	2008-10-24 11:00:31 UTC (rev 9529)
@@ -400,7 +400,7 @@
     /**Copies the symbology settings from another layer. Returns true in case of success*/
     bool copySymbologySettings(const QgsMapLayer& other);
 
-    bool isSymbologyCompatible(const QgsMapLayer& other) const;
+    bool hasCompatibleSymbology(const QgsMapLayer& other) const;
 
     /**
      * If an operation returns 0 (e.g. draw()), this function
@@ -408,7 +408,7 @@
      * Interactive users of this provider can then, for example,
      * call a QMessageBox to display the contents.
      */
-    QString errorCaptionString();
+    QString lastErrorTitle();
   
     /**
      * If an operation returns 0 (e.g. draw()), this function
@@ -416,7 +416,7 @@
      * Interactive users of this provider can then, for example,
      * call a QMessageBox to display the contents.
      */
-    QString errorString();
+    QString lastError();
 
     /** Returns the data provider
      *

Modified: trunk/qgis/python/core/qgsvectorlayer.sip
===================================================================
--- trunk/qgis/python/core/qgsvectorlayer.sip	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/python/core/qgsvectorlayer.sip	2008-10-24 11:00:31 UTC (rev 9529)
@@ -86,7 +86,7 @@
   bool copySymbologySettings(const QgsMapLayer& other);
 
   /** Returns true if this layer can be in the same symbology group with another layer */
-  bool isSymbologyCompatible(const QgsMapLayer& other) const;
+  bool hasCompatibleSymbology(const QgsMapLayer& other) const;
   
   /** Returns a pointer to the renderer */
   const QgsRenderer* renderer() const;

Modified: trunk/qgis/python/plugins/mapserver_export/ms_export.py
===================================================================
--- trunk/qgis/python/plugins/mapserver_export/ms_export.py	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/python/plugins/mapserver_export/ms_export.py	2008-10-24 11:00:31 UTC (rev 9529)
@@ -42,8 +42,8 @@
     self.mapName = ''
     self.width = ''
     self.height = ''
-    self.minScale = ''
-    self.maxScale = ''
+    self.minimumScale = ''
+    self.maximumScale = ''
     self.template = ''
     self.header = ''
     self.footer = ''
@@ -57,8 +57,8 @@
     self.mapName = mapname
     self.width = width
     self.height = height
-    #self.minScale = minscale
-    #self.maxScale = maxscale
+    #self.minimumScale = minscale
+    #self.maximumScale = maxscale
     self.template = template
     self.header = header
     self.footer = footer
@@ -218,10 +218,10 @@
     self.outFile.write("    END\n\n")
 
     self.outFile.write("    #Scale range at which web interface will operate\n")
-    if self.minScale != "":
-      self.outFile.write("    MINSCALE " + self.minScale + "\n") 
-    if self.maxScale != "":
-      self.outFile.write("    MAXSCALE " + self.maxScale + "\n") 
+    if self.minimumScale != "":
+      self.outFile.write("    MINSCALE " + self.minimumScale + "\n") 
+    if self.maximumScale != "":
+      self.outFile.write("    MAXSCALE " + self.maximumScale + "\n") 
 
     self.outFile.write("    # Template and header/footer settings\n")
     self.outFile.write("    # Only the template parameter is required to display a map. See MapServer documentation\n")
@@ -304,9 +304,9 @@
         layer_def += "    TYPE " + lyr.getAttribute("type").encode('utf-8').upper() + "\n"
  
       # Set min/max scales
-      if lyr.getAttribute('scaleBasedVisibilityFlag').encode('utf-8') == 1:
-        layer_def += "    MINSCALE " + lyr.getAttribute('minScale').encode('utf-8') + "\n"
-        layer_def += "    MAXSCALE " + lyr.getAttribute('maxScale').encode('utf-8') + "\n"
+      if lyr.getAttribute('hasScaleBasedVisibilityFlag').encode('utf-8') == 1:
+        layer_def += "    MINSCALE " + lyr.getAttribute('minimumScale').encode('utf-8') + "\n"
+        layer_def += "    MAXSCALE " + lyr.getAttribute('maximumScale').encode('utf-8') + "\n"
 
       # data
       dataString = lyr.getElementsByTagName("datasource")[0].childNodes[0].nodeValue.encode('utf-8')
@@ -383,11 +383,11 @@
       # the proj4 text string needs to be reformatted to make mapserver happy
       layer_def += self.formatProj4(proj4Text)
       layer_def += "    END\n"
-      scaleDependent = lyr.getAttribute("scaleBasedVisibilityFlag").encode('utf-8')
+      scaleDependent = lyr.getAttribute("hasScaleBasedVisibilityFlag").encode('utf-8')
       if scaleDependent == '1':
         # get the min and max scale settings
-        minscale = lyr.getAttribute("minScale").encode('utf-8')
-        maxscale = lyr.getAttribute("maxScale").encode('utf-8')
+        minscale = lyr.getAttribute("minimumScale").encode('utf-8')
+        maxscale = lyr.getAttribute("maximumScale").encode('utf-8')
         if minscale > '':
           layer_def += "    MINSCALE " + minscale + "\n"
         if maxscale > '':

Modified: trunk/qgis/src/app/legend/qgslegendlayerfilegroup.cpp
===================================================================
--- trunk/qgis/src/app/legend/qgslegendlayerfilegroup.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/app/legend/qgslegendlayerfilegroup.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -60,7 +60,7 @@
         {
           QgsMapLayer* childlayer = llf->layer();
           const QgsMapLayer* newlayer = ( dynamic_cast<const QgsLegendLayerFile*>( li ) )->layer();
-          if ( newlayer->isSymbologyCompatible( *childlayer ) )
+          if ( newlayer->hasCompatibleSymbology( *childlayer ) )
           {
             return INSERT;
           }
@@ -101,7 +101,7 @@
       return false;
     }
     QgsMapLayer* newLayer = ( dynamic_cast<QgsLegendLayerFile*>( newItem ) )->layer();
-    if ( newLayer->isSymbologyCompatible( *thelayer ) )
+    if ( newLayer->hasCompatibleSymbology( *thelayer ) )
     {
       insertChild( childCount(), newItem );
       return true;

Modified: trunk/qgis/src/app/qgisapp.cpp
===================================================================
--- trunk/qgis/src/app/qgisapp.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/app/qgisapp.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -5296,7 +5296,7 @@
                     SLOT( showProgress( int, int ) ) );
   // connect up any request the raster may make to update the statusbar message
   QObject::connect( theRasterLayer,
-                    SIGNAL( setStatus( QString ) ),
+                    SIGNAL( statusChanged( QString ) ),
                     this,
                     SLOT( showStatusMessage( QString ) ) );
   // notify the project we've made a change

Modified: trunk/qgis/src/app/qgsmapserverexport.cpp
===================================================================
--- trunk/qgis/src/app/qgsmapserverexport.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/app/qgsmapserverexport.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -149,11 +149,11 @@
       {
         mapFile << "  FOOTER " << txtWebFooter->text().toLocal8Bit().data() << std::endl;
       }
-      QString minScale = txtMinScale->text().isEmpty() ? "#MINSCALE" : "MINSCALE";
-      QString maxScale = txtMinScale->text().isEmpty() ? "  #MAXSCALE " : "  MAXSCALE ";
+      QString minimumScale = txtMinScale->text().isEmpty() ? "#MINSCALE" : "MINSCALE";
+      QString maximumScale = txtMinScale->text().isEmpty() ? "  #MAXSCALE " : "  MAXSCALE ";
       // write min and maxscale
-      mapFile << minScale.toLocal8Bit().data() << txtMinScale->text().toLocal8Bit().data() << std::endl;
-      mapFile << maxScale.toLocal8Bit().data() << txtMaxScale->text().toLocal8Bit().data() << std::endl;
+      mapFile << minimumScale.toLocal8Bit().data() << txtMinScale->text().toLocal8Bit().data() << std::endl;
+      mapFile << maximumScale.toLocal8Bit().data() << txtMaxScale->text().toLocal8Bit().data() << std::endl;
       // write comments about the imagepath and image url
       mapFile << "# Set IMAGEPATH to the path where mapserver should\n" <<
       "# write its output\n" <<

Modified: trunk/qgis/src/app/qgsmaptoolidentify.cpp
===================================================================
--- trunk/qgis/src/app/qgsmaptoolidentify.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/app/qgsmaptoolidentify.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -412,16 +412,16 @@
 {
   //   QMessageBox::warning(
   //     this,
-  //     mapLayer->errorCaptionString(),
+  //     mapLayer->lastErrorTitle(),
   //     tr("Could not draw") + " " + mapLayer->name() + " " + tr("because") + ":\n" +
-  //       mapLayer->errorString()
+  //       mapLayer->lastError()
   //   );
 
   QgsMessageViewer * mv = new QgsMessageViewer();
-  mv->setWindowTitle( mLayer->errorCaptionString() );
+  mv->setWindowTitle( mLayer->lastErrorTitle() );
   mv->setMessageAsPlainText(
     QObject::tr( "Could not identify objects on" ) + " " + mLayer->name() + " " + QObject::tr( "because" ) + ":\n" +
-    mLayer->errorString()
+    mLayer->lastError()
   );
   mv->exec(); // deletes itself on close
 }

Modified: trunk/qgis/src/app/qgsrasterlayerproperties.cpp
===================================================================
--- trunk/qgis/src/app/qgsrasterlayerproperties.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/app/qgsrasterlayerproperties.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -95,9 +95,9 @@
   connect( mColormapTreeWidget, SIGNAL( itemDoubleClicked( QTreeWidgetItem*, int ) ), this, SLOT( handleColormapTreeWidgetDoubleClick( QTreeWidgetItem*, int ) ) );
 
   // set up the scale based layer visibility stuff....
-  chkUseScaleDependentRendering->setChecked( lyr->scaleBasedVisibility() );
-  spinMinimumScale->setValue(( int )lyr->minScale() );
-  spinMaximumScale->setValue(( int )lyr->maxScale() );
+  chkUseScaleDependentRendering->setChecked( lyr->hasScaleBasedVisibility() );
+  spinMinimumScale->setValue(( int )lyr->minimumScale() );
+  spinMaximumScale->setValue(( int )lyr->maximumScale() );
 
   // build GUI components
   cboxColorMap->addItem( tr( "Grayscale" ) );
@@ -1439,9 +1439,9 @@
 
 
   // set up the scale based layer visibility stuff....
-  mRasterLayer->setScaleBasedVisibility( chkUseScaleDependentRendering->isChecked() );
-  mRasterLayer->setMinScale( spinMinimumScale->value() );
-  mRasterLayer->setMaxScale( spinMaximumScale->value() );
+  mRasterLayer->toggleScaleBasedVisibility( chkUseScaleDependentRendering->isChecked() );
+  mRasterLayer->setMinimumScale( spinMinimumScale->value() );
+  mRasterLayer->setMaximumScale( spinMaximumScale->value() );
 
   //update the legend pixmap
   pixmapLegend->setPixmap( mRasterLayer->getLegendQPixmap() );
@@ -1688,7 +1688,7 @@
   if ( mySelector->exec() )
   {
     QgsCoordinateReferenceSystem srs( mySelector->selectedCrsId(), QgsCoordinateReferenceSystem::InternalCrsId );
-    mRasterLayer->setSrs( srs );
+    mRasterLayer->setCrs( srs );
   }
   else
   {

Modified: trunk/qgis/src/app/qgsserversourceselect.cpp
===================================================================
--- trunk/qgis/src/app/qgsserversourceselect.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/app/qgsserversourceselect.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -334,7 +334,7 @@
 
   if ( mWmsProvider )
   {
-    connect( mWmsProvider, SIGNAL( setStatus( QString ) ), this, SLOT( showStatusMessage( QString ) ) );
+    connect( mWmsProvider, SIGNAL( statusChanged( QString ) ), this, SLOT( showStatusMessage( QString ) ) );
 
     // WMS Provider all set up; let's get some layers
 
@@ -622,18 +622,18 @@
 {
 //   QMessageBox::warning(
 //     this,
-//     wms->errorCaptionString(),
+//     wms->lastErrorTitle(),
 //     tr("Could not understand the response.  The") + " " + wms->name() + " " +
 //       tr("provider said") + ":\n" +
-//       wms->errorString()
+//       wms->lastError()
 //   );
 
   QgsMessageViewer * mv = new QgsMessageViewer( this );
-  mv->setWindowTitle( wms->errorCaptionString() );
+  mv->setWindowTitle( wms->lastErrorTitle() );
   mv->setMessageAsPlainText(
     tr( "Could not understand the response.  The" ) + " " + wms->name() + " " +
     tr( "provider said" ) + ":\n" +
-    wms->errorString()
+    wms->lastError()
   );
   mv->showMessage( true ); // Is deleted when closed
 }

Modified: trunk/qgis/src/app/qgsvectorlayerproperties.cpp
===================================================================
--- trunk/qgis/src/app/qgsvectorlayerproperties.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/app/qgsvectorlayerproperties.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -383,9 +383,9 @@
                                            layer->displayField() ) );
 
   // set up the scale based layer visibility stuff....
-  chkUseScaleDependentRendering->setChecked( layer->scaleBasedVisibility() );
-  spinMinimumScale->setValue(( int )layer->minScale() );
-  spinMaximumScale->setValue(( int )layer->maxScale() );
+  chkUseScaleDependentRendering->setChecked( layer->hasScaleBasedVisibility() );
+  spinMinimumScale->setValue(( int )layer->minimumScale() );
+  spinMaximumScale->setValue(( int )layer->maximumScale() );
 
   // symbology initialization
   if ( legendtypecombobox->count() == 0 )
@@ -484,9 +484,9 @@
   }
 #endif
   // set up the scale based layer visibility stuff....
-  layer->setScaleBasedVisibility( chkUseScaleDependentRendering->isChecked() );
-  layer->setMinScale( spinMinimumScale->value() );
-  layer->setMaxScale( spinMaximumScale->value() );
+  layer->toggleScaleBasedVisibility( chkUseScaleDependentRendering->isChecked() );
+  layer->setMinimumScale( spinMinimumScale->value() );
+  layer->setMaximumScale( spinMaximumScale->value() );
 
   // update the display field
   layer->setDisplayField( displayFieldComboBox->currentText() );
@@ -867,7 +867,7 @@
   if ( mySelector->exec() )
   {
     QgsCoordinateReferenceSystem srs( mySelector->selectedCrsId(), QgsCoordinateReferenceSystem::InternalCrsId );
-    layer->setSrs( srs );
+    layer->setCrs( srs );
   }
   else
   {

Modified: trunk/qgis/src/core/composer/qgscomposeritem.cpp
===================================================================
--- trunk/qgis/src/core/composer/qgscomposeritem.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/composer/qgscomposeritem.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -554,14 +554,14 @@
   p->restore();
 }
 
-double QgsComposerItem::textWidthMM( const QFont& font, const QString& text ) const
+double QgsComposerItem::textWidthMillimeters( const QFont& font, const QString& text ) const
 {
   QFont metricsFont = scaledFontPixelSize( font );
   QFontMetrics fontMetrics( metricsFont );
   return ( fontMetrics.width( text ) / FONT_WORKAROUND_SCALE );
 }
 
-double QgsComposerItem::fontAscentMM( const QFont& font ) const
+double QgsComposerItem::fontAscentMillimeters( const QFont& font ) const
 {
   QFont metricsFont = scaledFontPixelSize( font );
   QFontMetrics fontMetrics( metricsFont );

Modified: trunk/qgis/src/core/composer/qgscomposeritem.h
===================================================================
--- trunk/qgis/src/core/composer/qgscomposerlabel.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/composer/qgscomposerlabel.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -68,8 +68,8 @@
 
 void QgsComposerLabel::adjustSizeToText()
 {
-  double textWidth = textWidthMM( mFont, mText );
-  double fontAscent = fontAscentMM( mFont );
+  double textWidth = textWidthMillimeters( mFont, mText );
+  double fontAscent = fontAscentMillimeters( mFont );
 
   setSceneRect( QRectF( transform().dx(), transform().dy(), textWidth + 2 * mMargin + 2 * pen().widthF() + 1, \
                         fontAscent + 2 * mMargin + 2 * pen().widthF() + 1 ) );

Modified: trunk/qgis/src/core/composer/qgscomposerlegend.cpp
===================================================================
--- trunk/qgis/src/core/composer/qgscomposerlegend.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/composer/qgscomposerlegend.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -83,13 +83,13 @@
   //font metrics
 
   //draw title
-  currentYCoordinate += fontAscentMM( mTitleFont );
+  currentYCoordinate += fontAscentMillimeters( mTitleFont );
   if ( painter )
   {
     drawText( painter, mBoxSpace, currentYCoordinate, mTitle, mTitleFont );
   }
 
-  maxXCoord = 2 * mBoxSpace + textWidthMM( mTitleFont, mTitle );
+  maxXCoord = 2 * mBoxSpace + textWidthMillimeters( mTitleFont, mTitle );
 
   //draw layer items
   for ( int i = 0; i < numLayerItems; ++i )
@@ -98,7 +98,7 @@
     if ( currentLayerItem )
     {
       currentYCoordinate += mLayerSpace;
-      currentYCoordinate += fontAscentMM( mLayerFont );
+      currentYCoordinate += fontAscentMillimeters( mLayerFont );
 
       //draw layer Item
       if ( painter )
@@ -106,7 +106,7 @@
         drawText( painter, mBoxSpace, currentYCoordinate, currentLayerItem->text(), mLayerFont );
       }
 
-      maxXCoord = std::max( maxXCoord, 2 * mBoxSpace + textWidthMM( mLayerFont, currentLayerItem->text() ) );
+      maxXCoord = std::max( maxXCoord, 2 * mBoxSpace + textWidthMillimeters( mLayerFont, currentLayerItem->text() ) );
 
       //and child items
       drawLayerChildItems( painter, currentLayerItem, currentYCoordinate, maxXCoord );
@@ -149,7 +149,7 @@
   }
 
   //standerd item height
-  double itemHeight = std::max( mSymbolHeight, fontAscentMM( mItemFont ) );
+  double itemHeight = std::max( mSymbolHeight, fontAscentMillimeters( mItemFont ) );
 
   QStandardItem* currentItem;
 
@@ -201,10 +201,10 @@
     //finally draw text
     if ( p )
     {
-      drawText( p, currentXCoord, currentYCoord + fontAscentMM( mItemFont ) + ( realItemHeight - fontAscentMM( mItemFont ) ) / 2, currentItem->text(), mItemFont );
+      drawText( p, currentXCoord, currentYCoord + fontAscentMillimeters( mItemFont ) + ( realItemHeight - fontAscentMillimeters( mItemFont ) ) / 2, currentItem->text(), mItemFont );
     }
 
-    maxXCoord = std::max( maxXCoord, currentXCoord + textWidthMM( mItemFont, currentItem->text() ) + mBoxSpace );
+    maxXCoord = std::max( maxXCoord, currentXCoord + textWidthMillimeters( mItemFont, currentItem->text() ) + mBoxSpace );
 
     currentYCoord += realItemHeight;
   }

Modified: trunk/qgis/src/core/composer/qgscomposerscalebar.cpp
===================================================================
--- trunk/qgis/src/core/composer/qgscomposerscalebar.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/composer/qgscomposerscalebar.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -28,7 +28,7 @@
 #include <QPainter>
 #include <cmath>
 
-QgsComposerScaleBar::QgsComposerScaleBar( QgsComposition* composition ): QgsComposerItem( composition ), mComposerMap( 0 ), mStyle( 0 ), mSegmentMM( 0.0 )
+QgsComposerScaleBar::QgsComposerScaleBar( QgsComposition* composition ): QgsComposerItem( composition ), mComposerMap( 0 ), mStyle( 0 ), mSegmentMillimeters( 0.0 )
 {
   applyDefaultSettings();
 }
@@ -50,7 +50,7 @@
 
   //x-offset is half of first label width because labels are drawn centered
   QString firstLabel = firstLabelString();
-  double firstLabelWidth = textWidthMM( mFont, firstLabel );
+  double firstLabelWidth = textWidthMillimeters( mFont, firstLabel );
 
   mStyle->draw( painter, firstLabelWidth / 2 );
 
@@ -65,7 +65,7 @@
 void QgsComposerScaleBar::setNumUnitsPerSegment( double units )
 {
   mNumUnitsPerSegment = units;
-  refreshSegmentMM();
+  refreshSegmentMillimeters();
 }
 
 void QgsComposerScaleBar::setComposerMap( const QgsComposerMap* map )
@@ -82,7 +82,7 @@
   connect( mComposerMap, SIGNAL( extentChanged() ), this, SLOT( updateSegmentSize() ) );
   connect( mComposerMap, SIGNAL( destroyed( QObject* ) ), this, SLOT( invalidateCurrentMap() ) );
 
-  refreshSegmentMM();
+  refreshSegmentMillimeters();
 }
 
 void QgsComposerScaleBar::invalidateCurrentMap()
@@ -92,7 +92,7 @@
   mComposerMap = 0;
 }
 
-void QgsComposerScaleBar::refreshSegmentMM()
+void QgsComposerScaleBar::refreshSegmentMillimeters()
 {
   if ( mComposerMap )
   {
@@ -103,7 +103,7 @@
     QRectF composerItemRect = mComposerMap->rect();
 
     //calculate size depending on mNumUnitsPerSegment
-    mSegmentMM = composerItemRect.width() / composerMapRect.width() * mNumUnitsPerSegment;
+    mSegmentMillimeters = composerItemRect.width() / composerMapRect.width() * mNumUnitsPerSegment;
   }
 }
 
@@ -144,7 +144,7 @@
     mNumUnitsPerSegment = ( nPow10 / 2 ) * powerOf10;
   }
 
-  refreshSegmentMM();
+  refreshSegmentMillimeters();
   adjustBoxSize();
 }
 
@@ -167,7 +167,7 @@
 
 void QgsComposerScaleBar::updateSegmentSize()
 {
-  refreshSegmentMM();
+  refreshSegmentMillimeters();
   update();
 }
 
@@ -179,15 +179,15 @@
   //left segments
   for ( int i = 0; i < mNumSegmentsLeft; ++i )
   {
-    posWidthList.push_back( qMakePair( mCurrentXCoord, mSegmentMM / mNumSegmentsLeft ) );
-    mCurrentXCoord += mSegmentMM / mNumSegmentsLeft;
+    posWidthList.push_back( qMakePair( mCurrentXCoord, mSegmentMillimeters / mNumSegmentsLeft ) );
+    mCurrentXCoord += mSegmentMillimeters / mNumSegmentsLeft;
   }
 
   //right segments
   for ( int i = 0; i < mNumSegments; ++i )
   {
-    posWidthList.push_back( qMakePair( mCurrentXCoord, mSegmentMM ) );
-    mCurrentXCoord += mSegmentMM;
+    posWidthList.push_back( qMakePair( mCurrentXCoord, mSegmentMillimeters ) );
+    mCurrentXCoord += mSegmentMillimeters;
   }
 }
 
@@ -278,7 +278,7 @@
   composerScaleBarElem.setAttribute( "numSegments", mNumSegments );
   composerScaleBarElem.setAttribute( "numSegmentsLeft", mNumSegmentsLeft );
   composerScaleBarElem.setAttribute( "numUnitsPerSegment", mNumUnitsPerSegment );
-  composerScaleBarElem.setAttribute( "segmentMM", mSegmentMM );
+  composerScaleBarElem.setAttribute( "segmentMillimeters", mSegmentMillimeters );
   composerScaleBarElem.setAttribute( "numMapUnitsPerScaleBarUnit", mNumMapUnitsPerScaleBarUnit );
   composerScaleBarElem.setAttribute( "font", mFont.toString() );
   composerScaleBarElem.setAttribute( "outlineWidth", mPen.widthF() );
@@ -321,7 +321,7 @@
   mNumSegments = itemElem.attribute( "numSegments", "2" ).toInt();
   mNumSegmentsLeft = itemElem.attribute( "numSegmentsLeft", "0" ).toInt();
   mNumUnitsPerSegment = itemElem.attribute( "numUnitsPerSegment", "1.0" ).toDouble();
-  mSegmentMM = itemElem.attribute( "segmentMM", "0.0" ).toDouble();
+  mSegmentMillimeters = itemElem.attribute( "segmentMillimeters", "0.0" ).toDouble();
   mNumMapUnitsPerScaleBarUnit = itemElem.attribute( "numMapUnitsPerScaleBarUnit", "1.0" ).toDouble();
   mPen.setWidthF( itemElem.attribute( "outlineWidth", "1.0" ).toDouble() );
   mUnitLabeling = itemElem.attribute( "unitLabel" );
@@ -345,7 +345,7 @@
     mComposerMap = composerMap;
   }
 
-  refreshSegmentMM();
+  refreshSegmentMillimeters();
 
   //restore general composer item properties
   QDomNodeList composerItemList = itemElem.elementsByTagName( "ComposerItem" );

Modified: trunk/qgis/src/core/composer/qgscomposerscalebar.h
===================================================================
--- trunk/qgis/src/core/composer/qgscomposition.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/composer/qgscomposition.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -138,8 +138,8 @@
 int QgsComposition::pixelFontSize( double pointSize ) const
 {
   //in QgsComposition, one unit = one mm
-  double sizeMM = pointSize * 0.3527;
-  return ( sizeMM + 0.5 ); //round to nearest mm
+  double sizeMillimeters = pointSize * 0.3527;
+  return ( sizeMillimeters + 0.5 ); //round to nearest mm
 }
 
 double QgsComposition::pointFontSize( int pixelSize ) const

Modified: trunk/qgis/src/core/composer/qgsdoubleboxscalebarstyle.cpp
===================================================================
--- trunk/qgis/src/core/composer/qgsdoubleboxscalebarstyle.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/composer/qgsdoubleboxscalebarstyle.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -45,7 +45,7 @@
   {
     return;
   }
-  double barTopPosition = mScaleBar->fontAscentMM( mScaleBar->font() ) + mScaleBar->labelBarSpace() + mScaleBar->boxContentSpace();
+  double barTopPosition = mScaleBar->fontAscentMillimeters( mScaleBar->font() ) + mScaleBar->labelBarSpace() + mScaleBar->boxContentSpace();
   double segmentHeight = mScaleBar->height() / 2;
 
   p->save();

Modified: trunk/qgis/src/core/composer/qgsscalebarstyle.cpp
===================================================================
--- trunk/qgis/src/core/composer/qgsscalebarstyle.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/composer/qgsscalebarstyle.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -46,7 +46,7 @@
   p->setFont( mScaleBar->font() );
 
   QString firstLabel = mScaleBar->firstLabelString();
-  double xOffset =  mScaleBar->textWidthMM( mScaleBar->font(), firstLabel ) / 2;
+  double xOffset =  mScaleBar->textWidthMillimeters( mScaleBar->font(), firstLabel ) / 2;
 
   //double mCurrentXCoord = mScaleBar->pen().widthF() + mScaleBar->boxContentSpace();
   QList<QPair<double, double> > segmentInfo;
@@ -78,7 +78,7 @@
 
     if ( segmentCounter == 0 || segmentCounter >= nSegmentsLeft ) //don't draw label for intermediate left segments
     {
-      mScaleBar->drawText( p, segmentIt->first - mScaleBar->textWidthMM( mScaleBar->font(), currentNumericLabel ) / 2 + xOffset, mScaleBar->fontAscentMM( mScaleBar->font() ) + mScaleBar->boxContentSpace(), currentNumericLabel, mScaleBar->font() );
+      mScaleBar->drawText( p, segmentIt->first - mScaleBar->textWidthMillimeters( mScaleBar->font(), currentNumericLabel ) / 2 + xOffset, mScaleBar->fontAscentMillimeters( mScaleBar->font() ) + mScaleBar->boxContentSpace(), currentNumericLabel, mScaleBar->font() );
     }
 
     if ( segmentCounter >= nSegmentsLeft )
@@ -92,7 +92,7 @@
   if ( !segmentInfo.isEmpty() )
   {
     currentNumericLabel = QString::number( currentLabelNumber / mScaleBar->numMapUnitsPerScaleBarUnit() );
-    mScaleBar->drawText( p, segmentInfo.last().first + mScaleBar->segmentMM() - mScaleBar->textWidthMM( mScaleBar->font(), currentNumericLabel ) / 2 + xOffset, mScaleBar->fontAscentMM( mScaleBar->font() ) + mScaleBar->boxContentSpace(), currentNumericLabel + " " + mScaleBar->unitLabeling(), mScaleBar->font() );
+    mScaleBar->drawText( p, segmentInfo.last().first + mScaleBar->segmentMillimeters() - mScaleBar->textWidthMillimeters( mScaleBar->font(), currentNumericLabel ) / 2 + xOffset, mScaleBar->fontAscentMillimeters( mScaleBar->font() ) + mScaleBar->boxContentSpace(), currentNumericLabel + " " + mScaleBar->unitLabeling(), mScaleBar->font() );
   }
 
   p->restore();
@@ -106,14 +106,14 @@
   }
 
   //consider centered first label
-  double firstLabelLeft = mScaleBar->textWidthMM( mScaleBar->font(), mScaleBar->firstLabelString() ) / 2;
+  double firstLabelLeft = mScaleBar->textWidthMillimeters( mScaleBar->font(), mScaleBar->firstLabelString() ) / 2;
 
   //consider last number and label
 
   double largestLabelNumber = mScaleBar->numSegments() * mScaleBar->numUnitsPerSegment() / mScaleBar->numMapUnitsPerScaleBarUnit();
   QString largestNumberLabel = QString::number( largestLabelNumber );
   QString largestLabel = QString::number( largestLabelNumber ) + " " + mScaleBar->unitLabeling();
-  double largestLabelWidth = mScaleBar->textWidthMM( mScaleBar->font(), largestLabel ) - mScaleBar->textWidthMM( mScaleBar->font(), largestNumberLabel ) / 2;
+  double largestLabelWidth = mScaleBar->textWidthMillimeters( mScaleBar->font(), largestLabel ) - mScaleBar->textWidthMillimeters( mScaleBar->font(), largestNumberLabel ) / 2;
 
   double totalBarLength = 0.0;
 
@@ -127,7 +127,7 @@
   }
 
   double width =  firstLabelLeft + totalBarLength + 2 * mScaleBar->pen().widthF() + largestLabelWidth + 2 * mScaleBar->boxContentSpace();
-  double height = mScaleBar->height() + mScaleBar->labelBarSpace() + 2 * mScaleBar->boxContentSpace() + mScaleBar->fontAscentMM( mScaleBar->font() );
+  double height = mScaleBar->height() + mScaleBar->labelBarSpace() + 2 * mScaleBar->boxContentSpace() + mScaleBar->fontAscentMillimeters( mScaleBar->font() );
 
   return QRectF( mScaleBar->transform().dx(), mScaleBar->transform().dy(), width, height );
 }

Modified: trunk/qgis/src/core/composer/qgssingleboxscalebarstyle.cpp
===================================================================
--- trunk/qgis/src/core/composer/qgssingleboxscalebarstyle.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/composer/qgssingleboxscalebarstyle.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -40,7 +40,7 @@
   {
     return;
   }
-  double barTopPosition = mScaleBar->fontAscentMM( mScaleBar->font() ) + mScaleBar->labelBarSpace() + mScaleBar->boxContentSpace();
+  double barTopPosition = mScaleBar->fontAscentMillimeters( mScaleBar->font() ) + mScaleBar->labelBarSpace() + mScaleBar->boxContentSpace();
 
   p->save();
   p->setPen( p->pen() );

Modified: trunk/qgis/src/core/composer/qgsticksscalebarstyle.cpp
===================================================================
--- trunk/qgis/src/core/composer/qgsticksscalebarstyle.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/composer/qgsticksscalebarstyle.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -53,7 +53,7 @@
   {
     return;
   }
-  double barTopPosition = mScaleBar->fontAscentMM( mScaleBar->font() ) + mScaleBar->labelBarSpace() + mScaleBar->boxContentSpace();
+  double barTopPosition = mScaleBar->fontAscentMillimeters( mScaleBar->font() ) + mScaleBar->labelBarSpace() + mScaleBar->boxContentSpace();
   double middlePosition = barTopPosition + mScaleBar->height() / 2.0;
   double bottomPosition = barTopPosition + mScaleBar->height();
 
@@ -70,13 +70,13 @@
     switch ( mTickPosition )
     {
       case DOWN:
-        p->drawLine( xOffset + segmentIt->first, barTopPosition, xOffset + segmentIt->first + mScaleBar->segmentMM(), barTopPosition );
+        p->drawLine( xOffset + segmentIt->first, barTopPosition, xOffset + segmentIt->first + mScaleBar->segmentMillimeters(), barTopPosition );
         break;
       case MIDDLE:
-        p->drawLine( xOffset + segmentIt->first, middlePosition, xOffset + segmentIt->first + mScaleBar->segmentMM(), middlePosition );
+        p->drawLine( xOffset + segmentIt->first, middlePosition, xOffset + segmentIt->first + mScaleBar->segmentMillimeters(), middlePosition );
         break;
       case UP:
-        p->drawLine( xOffset + segmentIt->first, bottomPosition, xOffset + segmentIt->first + mScaleBar->segmentMM(), bottomPosition );
+        p->drawLine( xOffset + segmentIt->first, bottomPosition, xOffset + segmentIt->first + mScaleBar->segmentMillimeters(), bottomPosition );
         break;
     }
   }
@@ -84,7 +84,7 @@
   //draw last tick
   if ( !segmentInfo.isEmpty() )
   {
-    double lastTickPositionX = segmentInfo.last().first + mScaleBar->segmentMM();
+    double lastTickPositionX = segmentInfo.last().first + mScaleBar->segmentMillimeters();
     p->drawLine( lastTickPositionX + xOffset, barTopPosition, lastTickPositionX + xOffset, barTopPosition + mScaleBar->height() );
   }
 

Modified: trunk/qgis/src/core/qgshttptransaction.cpp
===================================================================
--- trunk/qgis/src/core/qgshttptransaction.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/qgshttptransaction.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -197,8 +197,8 @@
 
     // Do a passthrough for the status bar text
     connect(
-      &httprecurse, SIGNAL( setStatus( QString ) ),
-      this,        SIGNAL( setStatus( QString ) )
+      &httprecurse, SIGNAL( statusChanged( QString ) ),
+      this,        SIGNAL( statusChanged( QString ) )
     );
 
     httprecurse.getSynchronously( respondedContent, ( redirections + 1 ) );
@@ -294,7 +294,7 @@
              .arg( done );
   }
 
-  emit setStatus( status );
+  emit statusChanged( status );
 }
 
 
@@ -402,46 +402,46 @@
   {
     case QHttp::Unconnected:
       QgsDebugMsg( "There is no connection to the host." );
-      emit setStatus( QString( QObject::tr( "Not connected" ) ) );
+      emit statusChanged( QString( QObject::tr( "Not connected" ) ) );
       break;
 
     case QHttp::HostLookup:
       QgsDebugMsg( "A host name lookup is in progress." );
 
-      emit setStatus( QString( QObject::tr( "Looking up '%1'" ) )
+      emit statusChanged( QString( QObject::tr( "Looking up '%1'" ) )
                       .arg( httphost ) );
       break;
 
     case QHttp::Connecting:
       QgsDebugMsg( "An attempt to connect to the host is in progress." );
 
-      emit setStatus( QString( QObject::tr( "Connecting to '%1'" ) )
+      emit statusChanged( QString( QObject::tr( "Connecting to '%1'" ) )
                       .arg( httphost ) );
       break;
 
     case QHttp::Sending:
       QgsDebugMsg( "The client is sending its request to the server." );
 
-      emit setStatus( QString( QObject::tr( "Sending request '%1'" ) )
+      emit statusChanged( QString( QObject::tr( "Sending request '%1'" ) )
                       .arg( httpurl ) );
       break;
 
     case QHttp::Reading:
       QgsDebugMsg( "The client's request has been sent and the client is reading the server's response." );
 
-      emit setStatus( QString( QObject::tr( "Receiving reply" ) ) );
+      emit statusChanged( QString( QObject::tr( "Receiving reply" ) ) );
       break;
 
     case QHttp::Connected:
       QgsDebugMsg( "The connection to the host is open, but the client is neither sending a request, nor waiting for a response." );
 
-      emit setStatus( QString( QObject::tr( "Response is complete" ) ) );
+      emit statusChanged( QString( QObject::tr( "Response is complete" ) ) );
       break;
 
     case QHttp::Closing:
       QgsDebugMsg( "The connection is closing down, but is not yet closed. (The state will be Unconnected when the connection is closed.)" );
 
-      emit setStatus( QString( QObject::tr( "Closing down connection" ) ) );
+      emit statusChanged( QString( QObject::tr( "Closing down connection" ) ) );
       break;
   }
 

Modified: trunk/qgis/src/core/qgshttptransaction.h
===================================================================
--- trunk/qgis/src/core/qgshttptransaction.h	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/qgshttptransaction.h	2008-10-24 11:00:31 UTC (rev 9529)
@@ -105,7 +105,7 @@
     void setProgress( int theProgress, int theTotalSteps );
 
     /** \brief emit a signal to be caught by qgisapp and display a msg on status bar */
-    void setStatus( QString theStatusQString );
+    void statusChanged( QString theStatusQString );
 
 
   private:

Modified: trunk/qgis/src/core/qgsmaplayer.cpp
===================================================================
--- trunk/qgis/src/core/qgsmaplayer.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/qgsmaplayer.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -198,17 +198,17 @@
   }
 
   // use scale dependent visibility flag
-  QString scaleBasedVisibility = element.attribute( "scaleBasedVisibilityFlag" );
-  if ( "1" == scaleBasedVisibility )
+  QString hasScaleBasedVisibility = element.attribute( "hasScaleBasedVisibilityFlag" );
+  if ( "1" == hasScaleBasedVisibility )
   {
-    setScaleBasedVisibility( true );
+    toggleScaleBasedVisibility( true );
   }
   else
   {
-    setScaleBasedVisibility( false );
+    toggleScaleBasedVisibility( false );
   }
-  setMinScale( element.attribute( "minScale" ).toFloat() );
-  setMaxScale( element.attribute( "maxScale" ).toFloat() );
+  setMinimumScale( element.attribute( "minimumScale" ).toFloat() );
+  setMaximumScale( element.attribute( "maximumScale" ).toFloat() );
 
   // set name
   mnl = layer_node.namedItem( "layername" );
@@ -244,16 +244,16 @@
   QDomElement maplayer = document.createElement( "maplayer" );
 
   // use scale dependent visibility flag
-  if ( scaleBasedVisibility() )
+  if ( hasScaleBasedVisibility() )
   {
-    maplayer.setAttribute( "scaleBasedVisibilityFlag", 1 );
+    maplayer.setAttribute( "hasScaleBasedVisibilityFlag", 1 );
   }
   else
   {
-    maplayer.setAttribute( "scaleBasedVisibilityFlag", 0 );
+    maplayer.setAttribute( "hasScaleBasedVisibilityFlag", 0 );
   }
-  maplayer.setAttribute( "minScale", minScale() );
-  maplayer.setAttribute( "maxScale", maxScale() );
+  maplayer.setAttribute( "minimumScale", minimumScale() );
+  maplayer.setAttribute( "maximumScale", maximumScale() );
 
   // ID
   QDomElement id = document.createElement( "id" );
@@ -324,12 +324,12 @@
 }
 
 
-QString QgsMapLayer::errorCaptionString()
+QString QgsMapLayer::lastErrorTitle()
 {
   return QString();
 }
 
-QString QgsMapLayer::errorString()
+QString QgsMapLayer::lastError()
 {
   return QString();
 }
@@ -341,33 +341,33 @@
 
 
 
-void QgsMapLayer::setScaleBasedVisibility( bool theVisibilityFlag )
+void QgsMapLayer::toggleScaleBasedVisibility( bool theVisibilityFlag )
 {
   mScaleBasedVisibility = theVisibilityFlag;
 }
 
-bool QgsMapLayer::scaleBasedVisibility()
+bool QgsMapLayer::hasScaleBasedVisibility()
 {
   return mScaleBasedVisibility;
 }
 
-void QgsMapLayer::setMinScale( float theMinScale )
+void QgsMapLayer::setMinimumScale( float theMinScale )
 {
   mMinScale = theMinScale;
 }
 
-float QgsMapLayer::minScale()
+float QgsMapLayer::minimumScale()
 {
   return mMinScale;
 }
 
 
-void QgsMapLayer::setMaxScale( float theMaxScale )
+void QgsMapLayer::setMaximumScale( float theMaxScale )
 {
   mMaxScale = theMaxScale;
 }
 
-float QgsMapLayer::maxScale()
+float QgsMapLayer::maximumScale()
 {
   return mMaxScale;
 }
@@ -393,7 +393,7 @@
   return *mCRS;
 }
 
-void QgsMapLayer::setSrs( const QgsCoordinateReferenceSystem& srs )
+void QgsMapLayer::setCrs( const QgsCoordinateReferenceSystem& srs )
 {
   *mCRS = srs;
 }

Modified: trunk/qgis/src/core/qgsmaplayer.h
===================================================================
--- trunk/qgis/src/core/qgsmaplayer.h	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/qgsmaplayer.h	2008-10-24 11:00:31 UTC (rev 9529)
@@ -158,7 +158,7 @@
     virtual bool copySymbologySettings( const QgsMapLayer& other ) = 0;
 
     /** Returns true if this layer can be in the same symbology group with another layer */
-    virtual bool isSymbologyCompatible( const QgsMapLayer& other ) const = 0;
+    virtual bool hasCompatibleSymbology( const QgsMapLayer& other ) const = 0;
 
     /** Accessor for transparency level. */
     unsigned int getTransparency();
@@ -172,7 +172,7 @@
      * Interactive users of this provider can then, for example,
      * call a QMessageBox to display the contents.
      */
-    virtual QString errorCaptionString();
+    virtual QString lastErrorTitle();
 
     /**
      * If an operation returns 0 (e.g. draw()), this function
@@ -180,13 +180,13 @@
      * Interactive users of this provider can then, for example,
      * call a QMessageBox to display the contents.
      */
-    virtual QString errorString();
+    virtual QString lastError();
 
     /** Returns layer's spatial reference system */
     const QgsCoordinateReferenceSystem& srs();
 
     /** Sets layer's spatial reference system */
-    void setSrs( const QgsCoordinateReferenceSystem& srs );
+    void setCrs( const QgsCoordinateReferenceSystem& srs );
 
 
     /** A convenience function to capitalise the layer name */
@@ -265,16 +265,16 @@
     virtual void invalidTransformInput();
 
     /** Accessor and mutator for the minimum scale member */
-    void setMinScale( float theMinScale );
-    float minScale();
+    void setMinimumScale( float theMinScale );
+    float minimumScale();
 
     /** Accessor and mutator for the maximum scale member */
-    void setMaxScale( float theMaxScale );
-    float maxScale();
+    void setMaximumScale( float theMaxScale );
+    float maximumScale();
 
     /** Accessor and mutator for the scale based visilibility flag */
-    void setScaleBasedVisibility( bool theVisibilityFlag );
-    bool scaleBasedVisibility();
+    void toggleScaleBasedVisibility( bool theVisibilityFlag );
+    bool hasScaleBasedVisibility();
 
   signals:
 
@@ -282,7 +282,7 @@
     void drawingProgress( int theProgress, int theTotalSteps );
 
     /** Emit a signal with status (e.g. to be caught by QgisApp and display a msg on status bar) */
-    void setStatus( QString theStatusQString );
+    void statusChanged( QString theStatus );
 
     /** Emit a signal that layer name has been changed */
     void layerNameChanged();

Modified: trunk/qgis/src/core/qgsmaprenderer.cpp
===================================================================
--- trunk/qgis/src/core/qgsmaprenderer.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/qgsmaprenderer.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -284,13 +284,13 @@
     }
 
     QgsDebugMsg( "Rendering layer " + ml->name() );
-    QgsDebugMsg( "  Layer minscale " + QString( "%1" ).arg( ml->minScale() ) );
-    QgsDebugMsg( "  Layer maxscale " + QString( "%1" ).arg( ml->maxScale() ) );
-    QgsDebugMsg( "  Scale dep. visibility enabled? " + QString( "%1" ).arg( ml->scaleBasedVisibility() ) );
+    QgsDebugMsg( "  Layer minscale " + QString( "%1" ).arg( ml->minimumScale() ) );
+    QgsDebugMsg( "  Layer maxscale " + QString( "%1" ).arg( ml->maximumScale() ) );
+    QgsDebugMsg( "  Scale dep. visibility enabled? " + QString( "%1" ).arg( ml->hasScaleBasedVisibility() ) );
     QgsDebugMsg( "  Input extent: " + ml->extent().toString() );
 
-    if (( ml->scaleBasedVisibility() && ml->minScale() < mScale && ml->maxScale() > mScale )
-        || ( !ml->scaleBasedVisibility() ) )
+    if (( ml->hasScaleBasedVisibility() && ml->minimumScale() < mScale && ml->maximumScale() > mScale )
+        || ( !ml->hasScaleBasedVisibility() ) )
     {
       connect( ml, SIGNAL( drawingProgress( int, int ) ), this, SLOT( onDrawingProgress( int, int ) ) );
 
@@ -390,8 +390,8 @@
       {
         // only make labels if the layer is visible
         // after scale dep viewing settings are checked
-        if (( ml->scaleBasedVisibility() && ml->minScale() < mScale  && ml->maxScale() > mScale )
-            || ( !ml->scaleBasedVisibility() ) )
+        if (( ml->hasScaleBasedVisibility() && ml->minimumScale() < mScale  && ml->maximumScale() > mScale )
+            || ( !ml->hasScaleBasedVisibility() ) )
         {
           bool split = false;
 

Modified: trunk/qgis/src/core/qgsmaprenderer.h
===================================================================
--- trunk/qgis/src/core/qgsmaprenderer.h	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/qgsmaprenderer.h	2008-10-24 11:00:31 UTC (rev 9529)
@@ -45,7 +45,7 @@
   public:
 
     /**Output units for pen width and point marker width/height*/
-    enum OUTPUT_UNITS
+    enum OutputUnits
     {
       MM, //millimeters
       PIXEL
@@ -120,9 +120,9 @@
     //! returns CRS ID of destination spatial reference system
     const QgsCoordinateReferenceSystem& destinationSrs();
 
-    void setOutputUnits( OUTPUT_UNITS u ) {mOutputUnits = u;}
+    void setOutputUnits( OutputUnits u ) {mOutputUnits = u;}
 
-    OUTPUT_UNITS outputUnits() const {return mOutputUnits;}
+    OutputUnits outputUnits() const {return mOutputUnits;}
 
     //! returns current extent of layer set
     QgsRect fullExtent();
@@ -219,7 +219,7 @@
     QgsRenderContext mRenderContext;
 
     //!Output units
-    OUTPUT_UNITS mOutputUnits;
+    OutputUnits mOutputUnits;
 };
 
 #endif

Modified: trunk/qgis/src/core/qgsrasterdataprovider.h
===================================================================
--- trunk/qgis/src/core/qgsrasterdataprovider.h	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/qgsrasterdataprovider.h	2008-10-24 11:00:31 UTC (rev 9529)
@@ -139,7 +139,7 @@
      * call a QMessageBox to display the contents.
      *
      */
-    virtual QString errorCaptionString() = 0;
+    virtual QString lastErrorTitle() = 0;
 
     /**
      * \brief   Returns the verbose error text for the last error in this provider
@@ -150,7 +150,7 @@
      * call a QMessageBox to display the contents.
      *
      */
-    virtual QString errorString() = 0;
+    virtual QString lastError() = 0;
 
 
   protected:

Modified: trunk/qgis/src/core/qgsvectorlayer.cpp
===================================================================
--- trunk/qgis/src/core/qgsvectorlayer.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/qgsvectorlayer.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -3067,7 +3067,7 @@
   }
 }
 
-bool QgsVectorLayer::isSymbologyCompatible( const QgsMapLayer& other ) const
+bool QgsVectorLayer::hasCompatibleSymbology( const QgsMapLayer& other ) const
 {
   // vector layers are symbology compatible if they have the same type, the same sequence of numerical/ non numerical fields and the same field names
 

Modified: trunk/qgis/src/core/qgsvectorlayer.h
===================================================================
--- trunk/qgis/src/core/qgsvectorlayer.h	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/qgsvectorlayer.h	2008-10-24 11:00:31 UTC (rev 9529)
@@ -146,7 +146,7 @@
     bool copySymbologySettings( const QgsMapLayer& other );
 
     /** Returns true if this layer can be in the same symbology group with another layer */
-    bool isSymbologyCompatible( const QgsMapLayer& other ) const;
+    bool hasCompatibleSymbology( const QgsMapLayer& other ) const;
 
     /** Returns a pointer to the renderer */
     const QgsRenderer* renderer() const;

Modified: trunk/qgis/src/core/raster/qgsrasterlayer.cpp
===================================================================
--- trunk/qgis/src/core/raster/qgsrasterlayer.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/raster/qgsrasterlayer.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1096,7 +1096,7 @@
   {
     QgsDebugMsg( "Wanting a '" + mProviderKey + "' provider to draw this." );
 
-    emit setStatus( QString( "Retrieving using " ) + mProviderKey );
+    emit statusChanged( QString( "Retrieving using " ) + mProviderKey );
 
     QImage* image =
       mDataProvider->draw(
@@ -1114,8 +1114,8 @@
     if ( !image )
     {
       // An error occurred.
-      mErrorCaption = mDataProvider->errorCaptionString();
-      mError        = mDataProvider->errorString();
+      mErrorCaption = mDataProvider->lastErrorTitle();
+      mError        = mDataProvider->lastError();
 
       delete myRasterViewPort;
       return FALSE;
@@ -2147,7 +2147,7 @@
     return myRasterBandStats;
   }
   // only print message if we are actually gathering the stats
-  emit setStatus( QString( "Retrieving stats for " ) + name() );
+  emit statusChanged( QString( "Retrieving stats for " ) + name() );
   qApp->processEvents();
   QgsDebugMsg( "stats for band " + QString::number( theBandNo ) );
   GDALRasterBandH myGdalBand = GDALGetRasterBand( mGdalDataset, theBandNo );
@@ -2161,7 +2161,7 @@
 
   myRasterBandStats.elementCount = 0; // because we'll be counting only VALID pixels later
 
-  emit setStatus( QString( "Calculating stats for " ) + name() );
+  emit statusChanged( QString( "Calculating stats for " ) + name() );
   //reset the main app progress bar
   emit drawingProgress( 0, 0 );
 
@@ -4619,12 +4619,12 @@
 
   // Do a passthrough for the status bar text
   connect(
-    mDataProvider, SIGNAL( setStatus( QString ) ),
+    mDataProvider, SIGNAL( statusChanged( QString ) ),
     this,           SLOT( showStatusMessage( QString ) )
   );
   QgsDebugMsg( "(8 arguments) exiting." );
 
-  emit setStatus( "QgsRasterLayer created" );
+  emit statusChanged( "QgsRasterLayer created" );
 } // QgsRasterLayer ctor
 
 
@@ -4780,17 +4780,17 @@
 
   // Pass-through
   // TODO: See if we can connect signal-to-signal.  This is a kludge according to the Qt doc.
-  emit setStatus( theMessage );
+  emit statusChanged( theMessage );
 }
 
 
-QString QgsRasterLayer::errorCaptionString()
+QString QgsRasterLayer::lastErrorTitle()
 {
   return mErrorCaption;
 }
 
 
-QString QgsRasterLayer::errorString()
+QString QgsRasterLayer::lastError()
 {
   return mError;
 }

Modified: trunk/qgis/src/core/raster/qgsrasterlayer.h
===================================================================
--- trunk/qgis/src/core/raster/qgsrasterlayer.h	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/raster/qgsrasterlayer.h	2008-10-24 11:00:31 UTC (rev 9529)
@@ -737,7 +737,7 @@
       return false;
     } //todo
 
-    bool isSymbologyCompatible( const QgsMapLayer& other ) const
+    bool hasCompatibleSymbology( const QgsMapLayer& other ) const
     {
       //preventwarnings
       if ( other.type() < 0 )
@@ -753,7 +753,7 @@
      * Interactive users of this provider can then, for example,
      * call a QMessageBox to display the contents.
      */
-    QString errorCaptionString();
+    QString lastErrorTitle();
 
     /**
      * If an operation returns 0 (e.g. draw()), this function
@@ -761,7 +761,7 @@
      * Interactive users of this provider can then, for example,
      * call a QMessageBox to display the contents.
      */
-    QString errorString();
+    QString lastError();
 
     /** Returns the data provider
      *

Modified: trunk/qgis/src/gui/qgsmapcanvas.cpp
===================================================================
--- trunk/qgis/src/gui/qgsmapcanvas.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/gui/qgsmapcanvas.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1209,16 +1209,16 @@
 {
 //   QMessageBox::warning(
 //     this,
-//     mapLayer->errorCaptionString(),
+//     mapLayer->lastErrorTitle(),
 //     tr("Could not draw") + " " + mapLayer->name() + " " + tr("because") + ":\n" +
-//       mapLayer->errorString()
+//       mapLayer->lastError()
 //   );
 
   QgsMessageViewer * mv = new QgsMessageViewer( this );
-  mv->setWindowTitle( mapLayer->errorCaptionString() );
+  mv->setWindowTitle( mapLayer->lastErrorTitle() );
   mv->setMessageAsPlainText(
     tr( "Could not draw" ) + " " + mapLayer->name() + " " + tr( "because" ) + ":\n" +
-    mapLayer->errorString()
+    mapLayer->lastError()
   );
   mv->exec();
   //MH

Modified: trunk/qgis/src/providers/wfs/qgswfsprovider.cpp
===================================================================
--- trunk/qgis/src/providers/wfs/qgswfsprovider.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/providers/wfs/qgswfsprovider.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -271,7 +271,7 @@
   QgsWFSData dataReader( uri, &mExtent, &mSourceCRS, mFeatures, geometryAttribute, thematicAttributes, &mWKBType );
   QObject::connect( dataReader.http(), SIGNAL( dataReadProgress( int, int ) ), this, SLOT( handleWFSProgressMessage( int, int ) ) );
 
-  //also connect to setStatus signal of qgisapp (if it exists)
+  //also connect to statusChanged signal of qgisapp (if it exists)
   QWidget* mainWindow = 0;
 
   QWidgetList topLevelWidgets = qApp->topLevelWidgets();

Modified: trunk/qgis/src/providers/wms/qgswmsprovider.cpp
===================================================================
--- trunk/qgis/src/providers/wms/qgswmsprovider.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/providers/wms/qgswmsprovider.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -449,7 +449,7 @@
 
     // Do a passthrough for the status bar text
     connect(
-            &http, SIGNAL(setStatus        (QString)),
+            &http, SIGNAL( statusChanged        (QString)),
              this,   SLOT(showStatusMessage(QString))
            );
 
@@ -569,7 +569,7 @@
 
         // Do a passthrough for the status bar text
         connect(
-                &http, SIGNAL(setStatus        (QString)),
+                &http, SIGNAL( statusChanged        (QString)),
                  this,   SLOT(showStatusMessage(QString))
                );
 
@@ -625,7 +625,7 @@
 
   // Do a passthrough for the status bar text
   connect(
-    &http, SIGNAL( setStatus( QString ) ),
+    &http, SIGNAL( statusChanged( QString ) ),
     this,   SLOT( showStatusMessage( QString ) )
   );
 
@@ -678,7 +678,7 @@
 
   // Do a passthrough for the status bar text
   connect(
-    &http, SIGNAL( setStatus( QString ) ),
+    &http, SIGNAL( statusChanged( QString ) ),
     this,   SLOT( showStatusMessage( QString ) )
   );
 
@@ -1708,7 +1708,7 @@
 {
   // Pass-through
   // TODO: See if we can connect signal-to-signal.  This is a kludge according to the Qt doc.
-  emit setStatus( theMessage );
+  emit statusChanged( theMessage );
 }
 
 
@@ -2201,13 +2201,13 @@
 }
 
 
-QString QgsWmsProvider::errorCaptionString()
+QString QgsWmsProvider::lastErrorTitle()
 {
   return mErrorCaption;
 }
 
 
-QString QgsWmsProvider::errorString()
+QString QgsWmsProvider::lastError()
 {
   QgsDebugMsg( "returning '" + mError  + "'." );
   return mError;

Modified: trunk/qgis/src/providers/wms/qgswmsprovider.h
===================================================================
--- trunk/qgis/tests/testdata/landsat_875.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/landsat_875.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis projectname="" version="0.9.2-Ganymede" >
-        <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" type="raster" >
+        <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" type="raster" >
             <id>landsat_clip20080125220410500</id>
             <datasource>landsat_clip.tif</datasource>
             <layername>landsat_clip</layername>

Modified: trunk/qgis/tests/testdata/lines.qml
===================================================================
--- trunk/qgis/tests/testdata/lines.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/lines.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Line" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Line" type="vector" >
     <id>lines20080110101725388</id>
     <datasource>/Users/timlinux/dev/cpp/qgis_qml/tests/testdata/lines.shp</datasource>
     <layername>lines</layername>

Modified: trunk/qgis/tests/testdata/lines_continuous_symbol.qml
===================================================================
--- trunk/qgis/tests/testdata/lines_continuous_symbol.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/lines_continuous_symbol.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Line" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Line" type="vector" >
     <id>lines20080110101725388</id>
     <datasource>/Users/timlinux/dev/cpp/qgis_qml/tests/testdata/lines.shp</datasource>
     <layername>lines</layername>

Modified: trunk/qgis/tests/testdata/lines_graduated_symbol.qml
===================================================================
--- trunk/qgis/tests/testdata/lines_graduated_symbol.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/lines_graduated_symbol.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Line" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Line" type="vector" >
     <id>lines20080110101725388</id>
     <datasource>/Users/timlinux/dev/cpp/qgis_qml/tests/testdata/lines.shp</datasource>
     <layername>lines</layername>

Modified: trunk/qgis/tests/testdata/lines_single_symbol.qml
===================================================================
--- trunk/qgis/tests/testdata/lines_single_symbol.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/lines_single_symbol.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Line" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Line" type="vector" >
     <id>lines20080110101725388</id>
     <datasource>/Users/tim/dev/cpp/qgis/tests/testdata/lines.shp</datasource>
     <layername>lines</layername>

Modified: trunk/qgis/tests/testdata/lines_uniquevalue_symbol.qml
===================================================================
--- trunk/qgis/tests/testdata/lines_uniquevalue_symbol.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/lines_uniquevalue_symbol.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Line" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Line" type="vector" >
     <id>lines20080110101725388</id>
     <datasource>/Users/timlinux/dev/cpp/qgis_qml/tests/testdata/lines.shp</datasource>
     <layername>lines</layername>

Modified: trunk/qgis/tests/testdata/maprender_testdata.qml
===================================================================
--- trunk/qgis/tests/testdata/maprender_testdata.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/maprender_testdata.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Polygon" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Polygon" type="vector" >
     <id>maprender_testdata20080120093911087</id>
     <datasource>/tmp/maprender_testdata.shp</datasource>
     <layername>maprender_testdata</layername>

Modified: trunk/qgis/tests/testdata/points.qml
===================================================================
--- trunk/qgis/tests/testdata/points.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/points.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Point" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Point" type="vector" >
     <id>points20080109122431720</id>
     <datasource>/home/timlinux/dev/cpp/qgis/tests/testdata/points.shp</datasource>
     <layername>Points</layername>

Modified: trunk/qgis/tests/testdata/points_continuous_symbol.qml
===================================================================
--- trunk/qgis/tests/testdata/points_continuous_symbol.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/points_continuous_symbol.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Point" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Point" type="vector" >
     <id>points20080103150949100</id>
     <datasource>/Users/tim/dev/cpp/qgis/tests/testdata/points.shp</datasource>
     <layername>points</layername>

Modified: trunk/qgis/tests/testdata/points_graduated_symbol.qml
===================================================================
--- trunk/qgis/tests/testdata/points_graduated_symbol.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/points_graduated_symbol.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Point" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Point" type="vector" >
     <id>points20080103150949100</id>
     <datasource>/Users/tim/dev/cpp/qgis/tests/testdata/points.shp</datasource>
     <layername>points</layername>

Modified: trunk/qgis/tests/testdata/points_single_symbol.qml
===================================================================
--- trunk/qgis/tests/testdata/points_single_symbol.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/points_single_symbol.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Point" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Point" type="vector" >
     <id>points20080103150949100</id>
     <datasource>/Users/tim/dev/cpp/qgis/tests/testdata/points.shp</datasource>
     <layername>points</layername>

Modified: trunk/qgis/tests/testdata/points_uniquevalue_symbol.qml
===================================================================
--- trunk/qgis/tests/testdata/points_uniquevalue_symbol.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/points_uniquevalue_symbol.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Point" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Point" type="vector" >
     <id>points20080103150949100</id>
     <datasource>/Users/tim/dev/cpp/qgis/tests/testdata/points.shp</datasource>
     <layername>points</layername>

Modified: trunk/qgis/tests/testdata/polys.qml
===================================================================
--- trunk/qgis/tests/testdata/polys.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/polys.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Polygon" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Polygon" type="vector" >
     <id>polys20080110101725465</id>
     <datasource>/Users/timlinux/dev/cpp/qgis_qml/tests/testdata/polys.shp</datasource>
     <layername>polys</layername>

Modified: trunk/qgis/tests/testdata/polys_continuous_symbol.qml
===================================================================
--- trunk/qgis/tests/testdata/polys_continuous_symbol.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/polys_continuous_symbol.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Polygon" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Polygon" type="vector" >
     <id>polys20080110101725465</id>
     <datasource>/Users/timlinux/dev/cpp/qgis_qml/tests/testdata/polys.shp</datasource>
     <layername>polys</layername>

Modified: trunk/qgis/tests/testdata/polys_graduated_symbol.qml
===================================================================
--- trunk/qgis/tests/testdata/polys_graduated_symbol.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/polys_graduated_symbol.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Polygon" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Polygon" type="vector" >
     <id>polys20080110101725465</id>
     <datasource>/Users/timlinux/dev/cpp/qgis_qml/tests/testdata/polys.shp</datasource>
     <layername>polys</layername>

Modified: trunk/qgis/tests/testdata/polys_single_symbol.qml
===================================================================
--- trunk/qgis/tests/testdata/polys_single_symbol.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/polys_single_symbol.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Polygon" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Polygon" type="vector" >
     <id>polys20080110101725465</id>
     <datasource>/Users/tim/dev/cpp/qgis/tests/testdata/polys.shp</datasource>
     <layername>polys</layername>

Modified: trunk/qgis/tests/testdata/polys_uniquevalue_symbol.qml
===================================================================
--- trunk/qgis/tests/testdata/polys_uniquevalue_symbol.qml	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tests/testdata/polys_uniquevalue_symbol.qml	2008-10-24 11:00:31 UTC (rev 9529)
@@ -1,6 +1,6 @@
 <!DOCTYPE qgis PUBLIC 'http://mrcc.com/qgis.dtd' 'SYSTEM'>
 <qgis version="0.9.2-Ganymede" >
-  <maplayer minScale="1" maxScale="1e+08" scaleBasedVisibilityFlag="0" geometry="Polygon" type="vector" >
+  <maplayer minimumScale="1" maximumScale="1e+08" hasScaleBasedVisibilityFlag="0" geometry="Polygon" type="vector" >
     <id>polys20080110101725465</id>
     <datasource>/Users/timlinux/dev/cpp/qgis_qml/tests/testdata/polys.shp</datasource>
     <layername>polys</layername>

Modified: trunk/qgis/tools/mapserver_export/ms_export.py
===================================================================
--- trunk/qgis/tools/mapserver_export/ms_export.py	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tools/mapserver_export/ms_export.py	2008-10-24 11:00:31 UTC (rev 9529)
@@ -39,8 +39,8 @@
     self.mapName = ''
     self.width = ''
     self.height = ''
-    self.minScale = ''
-    self.maxScale = ''
+    self.minimumScale = ''
+    self.maximumScale = ''
     self.template = ''
     self.header = ''
     self.footer = ''
@@ -54,8 +54,8 @@
     self.mapName = mapname
     self.width = width
     self.height = height
-    #self.minScale = minscale
-    #self.maxScale = maxscale
+    #self.minimumScale = minscale
+    #self.maximumScale = maxscale
     self.template = template
     self.header = header
     self.footer = footer
@@ -213,10 +213,10 @@
     self.outFile.write("    END\n\n")
 
     self.outFile.write("    #Scale range at which web interface will operate\n")
-    if self.minScale != "":
-      self.outFile.write("    MINSCALE " + self.minScale + "\n") 
-    if self.maxScale != "":
-      self.outFile.write("    MAXSCALE " + self.maxScale + "\n") 
+    if self.minimumScale != "":
+      self.outFile.write("    MINSCALE " + self.minimumScale + "\n") 
+    if self.maximumScale != "":
+      self.outFile.write("    MAXSCALE " + self.maximumScale + "\n") 
 
     self.outFile.write("    # Template and header/footer settings\n")
     self.outFile.write("    # Only the template parameter is required to display a map. See MapServer documentation\n")
@@ -283,9 +283,9 @@
         self.outFile.write("    TYPE " + lyr.getAttribute("type").encode('utf-8').upper() + "\n")
  
       # Set min/max scales
-      if lyr.getAttribute('scaleBasedVisibilityFlag').encode('utf-8') == 1:
-        self.outFile.write("    MINSCALE " + lyr.getAttribute('minScale').encode('utf-8') + "\n")
-        self.outFile.write("    MAXSCALE " + lyr.getAttribute('maxScale').encode('utf-8') + "\n")
+      if lyr.getAttribute('hasScaleBasedVisibilityFlag').encode('utf-8') == 1:
+        self.outFile.write("    MINSCALE " + lyr.getAttribute('minimumScale').encode('utf-8') + "\n")
+        self.outFile.write("    MAXSCALE " + lyr.getAttribute('maximumScale').encode('utf-8') + "\n")
 
       # data
       dataString = lyr.getElementsByTagName("datasource")[0].childNodes[0].nodeValue.encode('utf-8')
@@ -361,11 +361,11 @@
       # the proj4 text string needs to be reformatted to make mapserver happy
       self.outFile.write(self.formatProj4(proj4Text))
       self.outFile.write("    END\n")
-      scaleDependent = lyr.getAttribute("scaleBasedVisibilityFlag").encode('utf-8')
+      scaleDependent = lyr.getAttribute("hasScaleBasedVisibilityFlag").encode('utf-8')
       if scaleDependent == '1':
         # get the min and max scale settings
-        minscale = lyr.getAttribute("minScale").encode('utf-8')
-        maxscale = lyr.getAttribute("maxScale").encode('utf-8')
+        minscale = lyr.getAttribute("minimumScale").encode('utf-8')
+        maxscale = lyr.getAttribute("maximumScale").encode('utf-8')
         if minscale > '':
           self.outFile.write("    MINSCALE " + minscale + "\n")
         if maxscale > '':

Modified: trunk/qgis/tools/mapserver_export/qgsmapserverexport.cpp
===================================================================
--- trunk/qgis/tools/mapserver_export/qgsmapserverexport.cpp	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/tools/mapserver_export/qgsmapserverexport.cpp	2008-10-24 11:00:31 UTC (rev 9529)
@@ -280,11 +280,11 @@
       {
         mapFile << "  FOOTER " << txtWebFooter->text().toLocal8Bit().data() << std::endl;
       }
-      QString minScale = txtMinScale->text().isEmpty()?"#MINSCALE":"MINSCALE";
-      QString maxScale = txtMinScale->text().isEmpty()?"  #MAXSCALE ":"  MAXSCALE ";
+      QString minimumScale = txtMinScale->text().isEmpty()?"#MINSCALE":"MINSCALE";
+      QString maximumScale = txtMinScale->text().isEmpty()?"  #MAXSCALE ":"  MAXSCALE ";
       // write min and maxscale
-      mapFile << minScale.toLocal8Bit().data() << txtMinScale->text().toLocal8Bit().data() << std::endl;
-      mapFile << maxScale.toLocal8Bit().data() << txtMaxScale->text().toLocal8Bit().data() << std::endl;
+      mapFile << minimumScale.toLocal8Bit().data() << txtMinScale->text().toLocal8Bit().data() << std::endl;
+      mapFile << maximumScale.toLocal8Bit().data() << txtMaxScale->text().toLocal8Bit().data() << std::endl;
       // write comments about the imagepath and image url
       mapFile << "# Set IMAGEPATH to the path where mapserver should\n" <<
         "# write its output\n" <<



More information about the QGIS-commit mailing list
--- trunk/qgis/src/core/composer/qgscomposeritem.h	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/composer/qgscomposeritem.h	2008-10-24 11:00:31 UTC (rev 9529)
@@ -123,11 +123,11 @@
     /**Like the above, but with a rectangle for multiline text*/
     void drawText( QPainter* p, const QRectF& rect, const QString& text, const QFont& font ) const;
 
-    /**Returns the font width in MM (considers upscaling and downscaling with FONT_WORKAROUND_SCALE*/
-    double textWidthMM( const QFont& font, const QString& text ) const;
+    /**Returns the font width in Millimeters (considers upscaling and downscaling with FONT_WORKAROUND_SCALE*/
+    double textWidthMillimeters( const QFont& font, const QString& text ) const;
 
-    /**Returns the font ascent in MM (considers upscaling and downscaling with FONT_WORKAROUND_SCALE*/
-    double fontAscentMM( const QFont& font ) const;
+    /**Returns the font ascent in Millimeters (considers upscaling and downscaling with FONT_WORKAROUND_SCALE*/
+    double fontAscentMillimeters( const QFont& font ) const;
 
     /**Calculates font to from point size to pixel size*/
     double pixelFontSize( double pointSize ) const;

Modified: trunk/qgis/src/core/composer/qgscomposerlabel.cpp
===================================================================
--- trunk/qgis/src/core/composer/qgscomposerscalebar.h	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/core/composer/qgscomposerscalebar.h	2008-10-24 11:00:31 UTC (rev 9529)
@@ -77,7 +77,7 @@
     double boxContentSpace() const {return mBoxContentSpace;}
     void setBoxContentSpace( double space ) {mBoxContentSpace = space;}
 
-    double segmentMM() const {return mSegmentMM;}
+    double segmentMillimeters() const {return mSegmentMillimeters;}
 
     /**Apply default settings (scale bar 1/5 of map item width)*/
     void applyDefaultSettings();
@@ -151,10 +151,10 @@
     double mBoxContentSpace;
 
     /**Width of a segment (in mm)*/
-    double mSegmentMM;
+    double mSegmentMillimeters;
 
-    /**Calculates with of a segment in mm and stores it in mSegmentMM*/
-    void refreshSegmentMM();
+    /**Calculates with of a segment in mm and stores it in mSegmentMillimeters*/
+    void refreshSegmentMillimeters();
 };
 
 #endif //QGSCOMPOSERSCALEBAR_H

Modified: trunk/qgis/src/core/composer/qgscomposition.cpp
===================================================================
--- trunk/qgis/src/providers/wms/qgswmsprovider.h	2008-10-23 20:03:19 UTC (rev 9528)
+++ trunk/qgis/src/providers/wms/qgswmsprovider.h	2008-10-24 11:00:31 UTC (rev 9529)
@@ -288,8 +288,8 @@
   std::vector<QgsWmsDataListUrlProperty>      dataListUrl;
   std::vector<QgsWmsFeatureListUrlProperty>   featureListUrl;
   std::vector<QgsWmsStyleProperty>            style;
-  double                                      minScaleDenominator;
-  double                                      maxScaleDenominator;
+  double                                      minimumScaleDenominator;
+  double                                      maximumScaleDenominator;
   std::vector<QgsWmsLayerProperty>            layer;      // nested layers
 
   // WMS layer attributes
@@ -355,7 +355,7 @@
      * \param[out] layers   The list of layers will be placed here.
      *
      * \retval FALSE if the layers could not be retrieved or parsed -
      *         see errorString() for more info
      *
      * \todo Document this better, make static
      */
@@ -424,7 +424,7 @@
     /** \brief   Renders the layer as an image
      *
      *  \return  A QImage - if the attempt to retrieve data for the draw was unsuccessful, returns 0
      *           and more information can be found in errorString() and errorCaptionString()
      *
      *  \todo    Add pixel depth parameter (intended to match the display or printer device)
      *
@@ -522,7 +522,7 @@
      * Interactive users of this provider can then, for example,
      * call a QMessageBox to display the contents.
      */
-    QString errorCaptionString();
+    QString lastErrorTitle();
 
     /**
      * \brief   Returns the verbose error text for the last error in this provider
@@ -533,7 +533,7 @@
      * call a QMessageBox to display the contents.
      */
 
-    QString errorString();
+    QString lastError();
 
     /** return a provider name
 
@@ -569,10 +569,10 @@
   signals:
 
     /** \brief emit a signal to notify of a progress event */
-    void setProgress( int theProgress, int theTotalSteps );
+    void progressChanged( int theProgress, int theTotalSteps );
 
     /** \brief emit a signal to be caught by qgisapp and display a msg on status bar */
-    void setStatus( QString const &  theStatusQString );
+    void statusChanged( QString const &  theStatusQString );
 
 
   public slots:
@@ -588,7 +588,7 @@
      * \param forceRefresh  if true, ignores any previous response cached in memory
      *                      and always contact the server for a new copy.
      * \retval FALSE if the capabilities document could not be retrieved or parsed -
      *         see errorString() for more info
      *
      * When this returns, "layers" will make sense.
      *
@@ -599,7 +599,7 @@
     /**
      * \brief Common URL retreival code for the differing WMS request types
      *
      * \retval 0 if an error occured - use errorString() and errorCaptionString() for details
      *
      */
     QByteArray retrieveUrl( QString url );
@@ -610,7 +610,7 @@
       bool downloadCapabilitiesURI(QString const &  uri);
     */
 
     //! \return FALSE if the capabilities document could not be parsed - see errorString() for more info
     bool parseCapabilitiesDom( QByteArray const & xml, QgsWmsCapabilitiesProperty& capabilitiesProperty );
 
     //! parse the WMS Service XML element
@@ -680,7 +680,7 @@
      * \brief Calculates the combined extent of the layers selected by layersDrawn
      *
      * \retval FALSE if the capabilities document could not be retrieved or parsed -
      *         see errorString() for more info
      */
     bool calculateExtent();
 
@@ -355,7 +355,7 @@
      *
      * \retval FALSE if the layers could not be retrieved or parsed -
-     *         see errorString() for more info
+     *         see lastError() for more info
      *
      * \todo Document this better, make static
@@ -424,7 +424,7 @@
      *
      *  \return  A QImage - if the attempt to retrieve data for the draw was unsuccessful, returns 0
-     *           and more information can be found in errorString() and errorCaptionString()
+     *           and more information can be found in lastError() and lastErrorTitle()
      *
      *  \todo    Add pixel depth parameter (intended to match the display or printer device)
@@ -588,7 +588,7 @@
      *                      and always contact the server for a new copy.
      * \retval FALSE if the capabilities document could not be retrieved or parsed -
-     *         see errorString() for more info
+     *         see lastError() for more info
      *
      * When this returns, "layers" will make sense.
@@ -599,7 +599,7 @@
      * \brief Common URL retreival code for the differing WMS request types
      *
-     * \retval 0 if an error occured - use errorString() and errorCaptionString() for details
+     * \retval 0 if an error occured - use lastError() and lastErrorTitle() for details
      *
      */
@@ -610,7 +610,7 @@
     */
 
-    //! \return FALSE if the capabilities document could not be parsed - see errorString() for more info
+    //! \return FALSE if the capabilities document could not be parsed - see lastError() for more info
     bool parseCapabilitiesDom( QByteArray const & xml, QgsWmsCapabilitiesProperty& capabilitiesProperty );
 
@@ -680,7 +680,7 @@
      *
      * \retval FALSE if the capabilities document could not be retrieved or parsed -
-     *         see errorString() for more info
+     *         see lastError() for more info
      */
     bool calculateExtent();

Modified: trunk/qgis/tests/testdata/landsat_875.qml
===================================================================